@@ -3,7 +3,7 @@ import logging
 import subprocess
 
 from typing import Optional, Callable, List, Tuple, Set, Dict, Type, cast
-from os import environ, name as osname
+from os import environ
 from signal import SIGTERM
 from socket import error as SocketError
 from datetime import datetime
@@ -47,7 +47,7 @@ logger = logging.getLogger('grizzly.locust')
 def greenlet_exception_logger(logger: logging.Logger, level: int = logging.CRITICAL) -> Callable[[gevent.Greenlet], None]:
     def exception_handler(greenlet: gevent.Greenlet) -> None:
         global unhandled_greenlet_exception
-        logger.log(level, f'unhandled exception in greenlet: {greenlet}', exc_info=True)
+        logger.log(level, f'unhandled exception in greenlet: {greenlet}: {greenlet.value}', exc_info=True)
         unhandled_greenlet_exception = True
 
     return exception_handler
@@ -146,7 +146,7 @@ def setup_locust_scenarios(grizzly: GrizzlyContext) -> Tuple[List[Type[GrizzlyUs
 
 
 def setup_resource_limits(context: Context) -> None:
-    if osname != 'nt' and on_master(context):
+    if sys.platform != 'win32' and on_master(context):
         try:
             import resource
             minimum_open_file_limit = 10000
@@ -223,7 +223,7 @@ def setup_environment_listeners(context: Context, environment: Environment, task
 
 def print_scenario_summary(grizzly: GrizzlyContext) -> None:
     def print_table_lines(max_length_iterations: int, max_length_description: int) -> None:
-        sys.stdout.write('-' * 10)
+        sys.stdout.write('-' * 5)
         sys.stdout.write('-|-')
         sys.stdout.write('-' * max_length_iterations)
         sys.stdout.write('|-')
@@ -245,7 +245,7 @@ def print_scenario_summary(grizzly: GrizzlyContext) -> None:
 
     for scenario in grizzly.scenarios():
         description = scenario.description or 'unknown'
-        row = '{:10}   {:>{}}  {}'.format(
+        row = '{:5}   {:>{}}  {}'.format(
             scenario.identifier,
             scenario.iterations,
             max_length_iterations,
@@ -254,7 +254,7 @@ def print_scenario_summary(grizzly: GrizzlyContext) -> None:
         rows.append(row)
 
     print('Scenario')
-    print('{:10}   {:>{}}  {}'.format('identifier', '#', max_length_iterations, 'description'))
+    print('{:5}   {:>{}}  {}'.format('ident', '#', max_length_iterations, 'description'))
     print_table_lines(max_length_iterations, max_length_description)
     for row in rows:
         print(row)
