@@ -2,12 +2,12 @@
 from typing import cast
 
 from behave.runner import Context
-from behave import register_type, then  # pylint: disable=no-name-in-module
+from behave import register_type, then, given  # pylint: disable=no-name-in-module
 
 from ..helpers import add_request_task, get_task_client, is_template
 from ...types import RequestDirection, RequestMethod
 from ...context import GrizzlyContext
-from ...tasks import PrintTask, WaitTask, TransformerTask, UntilRequestTask, DateTask
+from ...tasks import PrintTask, WaitTask, TransformerTask, UntilRequestTask, DateTask, AsyncRequestGroupTask
 
 from grizzly_extras.transformer import TransformerContentType
 
@@ -40,15 +40,17 @@ def step_task_request_with_name_to_endpoint_until(context: Context, method: Requ
 
     `condition` is a JSON- or Xpath expression, that also has support for "grizzly style" arguments:
 
-    - `retries` (int): maximum number of times to repeat the request if `condition` is not met (default `3`)
-
-    - `wait` (float): number of seconds to wait between retries (default `1.0`)
-
     Args:
         method (RequestMethod): type of request
         name (str): name of the requests in logs, can contain variables
         direction (RequestDirection): one of `to` or `from` depending on the value of `method`
         endpoint (str): URI relative to `host` in the scenario, can contain variables and in certain cases `user_class_name` specific parameters
+
+    ## Arguments:
+
+    * `retries` (int): maximum number of times to repeat the request if `condition` is not met (default `3`)
+
+    * `wait` (float): number of seconds to wait between retries (default `1.0`)
     '''
 
     assert method.direction == RequestDirection.FROM, 'this step is only valid for request methods with direction FROM'
@@ -58,6 +60,8 @@ def step_task_request_with_name_to_endpoint_until(context: Context, method: Requ
 
     grizzly = cast(GrizzlyContext, context.grizzly)
 
+    assert grizzly.scenario.async_group is None, f'until tasks cannot be in an async request group, close group {grizzly.scenario.async_group.name} first'
+
     for request_task, substitues in request_tasks:
         condition_rendered = condition
         for key, value in substitues.items():
@@ -419,7 +423,9 @@ def step_task_date(context: Context, value: str, variable: str) -> None:
     At least one of the following optional arguments **must** be specified:
 
     * `format` _str_ - a python [`strftime` format string](https://docs.python.org/3/library/datetime.html#strftime-and-strptime-format-codes), this argument is required
+
     * `timezone` _str_ (optional) - a valid [timezone name](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones)
+
     * `offset` _str_ (optional) - a time span string describing the offset, Y = years, M = months, D = days, h = hours, m = minutes, s = seconds, e.g. `1Y-2M10D`
     '''
     grizzly = cast(GrizzlyContext, context.grizzly)
@@ -429,3 +435,49 @@ def step_task_date(context: Context, value: str, variable: str) -> None:
         value=value,
         variable=variable,
     ))
+
+
+@given(u'an async request group with name "{name}"')
+def step_task_async_group_start(context: Context, name: str) -> None:
+    '''Creates a group of requests that should be executed asynchronously. All requests tasks created after this step will be added to the
+    request group, until the group is closed.
+
+    ```gherkin
+    Given an async request group with name "async-group-1"
+    Then put "test-file.json" to "bs://my-storage?AccountKey=aaaabbb=&Container=my-container" as "uploaded-test-file.json"
+    Then get "https://www.example.org/example.json" and save response in "example_openapi"
+    And close async request group
+    ```
+
+    In this example, the `put` and `get` requests will run asynchronously, and both requests will block following requests until both are finished.
+
+    Args:
+        name (str): name of the group, will be used in locust statistics
+    '''
+    grizzly = cast(GrizzlyContext, context.grizzly)
+
+    assert grizzly.scenario.async_group is None, f'async request group "{grizzly.scenario.async_group.name}" has not been closed'
+
+    grizzly.scenario.async_group = AsyncRequestGroupTask(name=name)
+
+
+@then(u'close async request group')
+def step_task_async_group_close(context: Context) -> None:
+    '''Closes an open async request group, to end the "boxing" of requests that should run asynchronously.
+
+    Must be preceeded by the expression `Given an async request group with name..." expression, and one or more requests expressions.
+
+    ```gherkin
+    Given an async request group with name "async-group-1"
+    Then put "test-file.json" to "bs://my-storage?AccountKey=aaaabbb=&Container=my-container" as "uploaded-test-file.json"
+    Then get "https://www.example.org/example.json" and save response in "example_openapi"
+    And close async request group
+    ```
+    '''
+    grizzly = cast(GrizzlyContext, context.grizzly)
+
+    assert grizzly.scenario.async_group is not None, 'no async request group is open'
+    assert len(grizzly.scenario.async_group.requests) > 0, f'there are no requests in async group "{grizzly.scenario.async_group.name}"'
+
+    grizzly.scenario.add_task(grizzly.scenario.async_group)
+    grizzly.scenario.async_group = None
