@@ -1,5 +1,5 @@
 from abc import ABC
-from typing import TYPE_CHECKING, Any, Callable, List, Type, Set
+from typing import TYPE_CHECKING, Any, Callable, List, Type, Set, Optional
 from os import environ
 from pathlib import Path
 
@@ -15,11 +15,13 @@ class GrizzlyTask(ABC):
 
     scenario: 'GrizzlyContextScenario'
 
-    def __init__(self) -> None:
+    def __init__(self, scenario: Optional['GrizzlyContextScenario'] = None) -> None:
         self._context_root = environ.get('GRIZZLY_CONTEXT_ROOT', '.')
+        if scenario is not None:
+            self.scenario = scenario
 
     def __call__(self) -> Callable[['GrizzlyScenario'], Any]:
-        raise NotImplementedError(f'{self.__class__.__name__} has not implemented "implementation"')
+        raise NotImplementedError(f'{self.__class__.__name__} has not been implemented')
 
     def get_templates(self) -> List[str]:
         def is_template(value: str) -> bool:
@@ -76,6 +78,7 @@ from .print import PrintTask
 from .transformer import TransformerTask
 from .until import UntilRequestTask
 from .date import DateTask
+from .async_group import AsyncRequestGroupTask
 
 
 __all__ = [
@@ -87,4 +90,5 @@ __all__ = [
     'TransformerTask',
     'UntilRequestTask',
     'DateTask',
+    'AsyncRequestGroupTask',
 ]
