@@ -28,6 +28,7 @@ from .request import RequestTask
 from . import GrizzlyTask, template
 
 if TYPE_CHECKING:  # pragma: no cover
+    from ..context import GrizzlyContextScenario
     from ..scenarios import GrizzlyScenario
 
 
@@ -43,8 +44,8 @@ class UntilRequestTask(GrizzlyTask):
     wait: float
     expected_matches: int
 
-    def __init__(self, request: RequestTask, condition: str) -> None:
-        super().__init__()
+    def __init__(self, request: RequestTask, condition: str, scenario: Optional['GrizzlyContextScenario'] = None) -> None:
+        super().__init__(scenario)
 
         self.request = request
         self.condition = condition
@@ -98,6 +99,7 @@ class UntilRequestTask(GrizzlyTask):
             number_of_matches = 0
             retry = 0
             exception: Optional[Exception] = None
+            response_length = 0
 
             start = time()
 
@@ -109,8 +111,10 @@ class UntilRequestTask(GrizzlyTask):
                         gsleep(self.wait)
 
                         _, payload = parent.user.request(self.request)
+
                         if payload is not None:
                             transformed = transform.transform(payload)
+                            response_length += len(payload)
                         else:
                             raise TransformerError('response payload was not set')
 
@@ -118,38 +122,40 @@ class UntilRequestTask(GrizzlyTask):
                         parent.logger.debug(f'{payload=}, condition={condition_rendered}, {matches=}')
                         number_of_matches = len(matches)
                     except Exception as e:
-                        exception = e
-                        number_of_matches = 0
                         parent.logger.error(f'{task_name}: loop retry={retry}', exc_info=True)
-
-                    if number_of_matches == self.expected_matches:
-                        break
-                    else:
-                        retry += 1
+                        if exception is None:
+                            exception = e
+                        number_of_matches = 0
+                    finally:
+                        if number_of_matches == self.expected_matches:
+                            break
+                        else:
+                            retry += 1
             except Exception as e:
-                exception = e
                 parent.logger.error(f'{task_name}: done retry={retry}', exc_info=True)
+                if exception is None:
+                    exception = e
+            finally:
+                response_time = int((time() - start) * 1000)
 
-            response_time = int((time() - start) * 1000)
+                if number_of_matches == self.expected_matches:
+                    exception = None
+                elif exception is None and number_of_matches != self.expected_matches:
+                    exception = RuntimeError((
+                        f'found {number_of_matches} matching values for {condition_rendered} in payload '
+                        f'after {retry} retries and {response_time} milliseconds'
+                    ))
 
-            if number_of_matches == self.expected_matches:
-                exception = None
-            elif exception is None and number_of_matches != self.expected_matches:
-                exception = RuntimeError((
-                    f'found {number_of_matches} matching values for {condition_rendered} in payload '
-                    f'after {retry} retries and {response_time} milliseconds'
-                ))
+                parent.user.environment.events.request.fire(
+                    request_type='UNTL',
+                    name=task_name,
+                    response_time=response_time,
+                    response_length=response_length,
+                    context=parent.user._context,
+                    exception=exception,
+                )
 
-            parent.user.environment.events.request.fire(
-                request_type='UNTL',
-                name=task_name,
-                response_time=response_time,
-                response_length=0,
-                context=parent.user._context,
-                exception=exception,
-            )
-
-            if exception is not None and self.request.scenario.failure_exception is not None:
-                raise self.request.scenario.failure_exception()
+                if exception is not None and self.request.scenario.failure_exception is not None:
+                    raise self.request.scenario.failure_exception()
 
         return task
